@@ -23,7 +23,7 @@ import lombok.Getter;
 
 import java.util.List;
 
-public class SingleChoiceOption<T> extends Option {
+public class SingleChoiceOption<T> extends Option<T> {
 
     @Getter private final List<T> optionValues;
 
@@ -32,4 +32,10 @@ public class SingleChoiceOption<T> extends Option {
         super(key, typeReference, defaultValue);
         this.optionValues = optionValues;
     }
+
+    @Override
+    public SingleChoiceOption<T> withDescription(String description) {
+        this.description = description;
+        return this;
+    }
 }
