@@ -34,6 +34,25 @@ public class PrimaryKey implements Serializable {
 
     private final List<String> columnNames;
 
+    private Boolean enableAutoId;
+
+    public PrimaryKey(String primaryKey, List<String> columnNames) {
+        this.primaryKey = primaryKey;
+        this.columnNames = columnNames;
+        this.enableAutoId = null;
+    }
+
+    public static boolean isPrimaryKeyField(PrimaryKey primaryKey, String fieldName) {
+        if (primaryKey == null || primaryKey.getColumnNames() == null) {
+            return false;
+        }
+        return primaryKey.getColumnNames().contains(fieldName);
+    }
+
+    public static PrimaryKey of(String primaryKey, List<String> columnNames, Boolean autoId) {
+        return new PrimaryKey(primaryKey, columnNames, autoId);
+    }
+
     public static PrimaryKey of(String primaryKey, List<String> columnNames) {
         return new PrimaryKey(primaryKey, columnNames);
     }
