@@ -28,7 +28,7 @@ public final class SeaTunnelRow implements Serializable {
     /** Table identifier. */
     private String tableId = "";
     /** The kind of change that a row describes in a changelog. */
-    private RowKind kind = RowKind.INSERT;
+    private RowKind rowKind = RowKind.INSERT;
     /** The array to store the actual internal format values. */
     private final Object[] fields;
 
@@ -50,8 +50,8 @@ public final class SeaTunnelRow implements Serializable {
         this.tableId = tableId;
     }
 
-    public void setRowKind(RowKind kind) {
-        this.kind = kind;
+    public void setRowKind(RowKind rowKind) {
+        this.rowKind = rowKind;
     }
 
     public int getArity() {
@@ -63,7 +63,7 @@ public final class SeaTunnelRow implements Serializable {
     }
 
     public RowKind getRowKind() {
-        return this.kind;
+        return this.rowKind;
     }
 
     public Object[] getFields() {
@@ -320,13 +320,13 @@ public final class SeaTunnelRow implements Serializable {
         }
         SeaTunnelRow that = (SeaTunnelRow) o;
         return Objects.equals(tableId, that.tableId)
-                && kind == that.kind
+                && rowKind == that.rowKind
                 && Arrays.deepEquals(fields, that.fields);
     }
 
     @Override
     public int hashCode() {
-        int result = Objects.hash(tableId, kind);
+        int result = Objects.hash(tableId, rowKind);
         result = 31 * result + Arrays.deepHashCode(fields);
         return result;
     }
@@ -337,7 +337,7 @@ public final class SeaTunnelRow implements Serializable {
                 + "tableId="
                 + tableId
                 + ", kind="
-                + kind.shortString()
+                + rowKind.shortString()
                 + ", fields="
                 + Arrays.toString(fields)
                 + '}';
