@@ -18,37 +18,42 @@
 package org.apache.seatunnel.connectors.seatunnel.amazondynamodb.source;
 
 import org.apache.seatunnel.api.source.Collector;
+import org.apache.seatunnel.api.source.SourceReader;
 import org.apache.seatunnel.api.table.type.SeaTunnelRow;
 import org.apache.seatunnel.api.table.type.SeaTunnelRowType;
 import org.apache.seatunnel.connectors.seatunnel.amazondynamodb.config.AmazonDynamoDBSourceOptions;
 import org.apache.seatunnel.connectors.seatunnel.amazondynamodb.serialize.DefaultSeaTunnelRowDeserializer;
 import org.apache.seatunnel.connectors.seatunnel.amazondynamodb.serialize.SeaTunnelRowDeserializer;
-import org.apache.seatunnel.connectors.seatunnel.common.source.AbstractSingleSplitReader;
-import org.apache.seatunnel.connectors.seatunnel.common.source.SingleSplitReaderContext;
 
 import lombok.extern.slf4j.Slf4j;
 import software.amazon.awssdk.auth.credentials.AwsBasicCredentials;
 import software.amazon.awssdk.auth.credentials.StaticCredentialsProvider;
 import software.amazon.awssdk.regions.Region;
 import software.amazon.awssdk.services.dynamodb.DynamoDbClient;
-import software.amazon.awssdk.services.dynamodb.model.AttributeValue;
 import software.amazon.awssdk.services.dynamodb.model.ScanRequest;
-import software.amazon.awssdk.services.dynamodb.model.ScanResponse;
+import software.amazon.awssdk.services.dynamodb.paginators.ScanIterable;
 
-import java.io.IOException;
 import java.net.URI;
-import java.util.Map;
+import java.util.ArrayList;
+import java.util.List;
+import java.util.Objects;
+import java.util.Queue;
+import java.util.concurrent.ConcurrentLinkedDeque;
 
 @Slf4j
-public class AmazonDynamoDBSourceReader extends AbstractSingleSplitReader<SeaTunnelRow> {
+public class AmazonDynamoDBSourceReader
+        implements SourceReader<SeaTunnelRow, AmazonDynamoDBSourceSplit> {
 
     protected DynamoDbClient dynamoDbClient;
-    protected SingleSplitReaderContext context;
+    protected SourceReader.Context context;
     protected AmazonDynamoDBSourceOptions amazondynamodbSourceOptions;
     protected SeaTunnelRowDeserializer seaTunnelRowDeserializer;
+    Queue<AmazonDynamoDBSourceSplit> pendingSplits = new ConcurrentLinkedDeque<>();
+
+    private volatile boolean noMoreSplit;
 
     public AmazonDynamoDBSourceReader(
-            SingleSplitReaderContext context,
+            SourceReader.Context context,
             AmazonDynamoDBSourceOptions amazondynamodbSourceOptions,
             SeaTunnelRowType typeInfo) {
         this.context = context;
@@ -57,7 +62,7 @@ public class AmazonDynamoDBSourceReader extends AbstractSingleSplitReader<SeaTun
     }
 
     @Override
-    public void open() throws Exception {
+    public void open() {
         dynamoDbClient =
                 DynamoDbClient.builder()
                         .endpointOverride(URI.create(amazondynamodbSourceOptions.getUrl()))
@@ -73,32 +78,69 @@ public class AmazonDynamoDBSourceReader extends AbstractSingleSplitReader<SeaTun
     }
 
     @Override
-    public void close() throws IOException {
+    public void close() {
         dynamoDbClient.close();
     }
 
     @Override
     @SuppressWarnings("magicnumber")
-    public void pollNext(Collector<SeaTunnelRow> output) throws Exception {
-        Map<String, AttributeValue> lastKeyEvaluated = null;
-
-        ScanResponse scan;
-        do {
-            scan =
-                    dynamoDbClient.scan(
-                            ScanRequest.builder()
-                                    .tableName(amazondynamodbSourceOptions.getTable())
-                                    .exclusiveStartKey(lastKeyEvaluated)
-                                    .build());
-            if (scan.hasItems()) {
-                scan.items()
-                        .forEach(
-                                item -> {
-                                    output.collect(seaTunnelRowDeserializer.deserialize(item));
-                                });
+    public void pollNext(Collector<SeaTunnelRow> output) throws InterruptedException {
+        synchronized (output.getCheckpointLock()) {
+            AmazonDynamoDBSourceSplit split = pendingSplits.poll();
+            if (split == null) {
+                log.info(
+                        "AmazonDynamoDB Source Reader [{}] waiting for splits",
+                        context.getIndexOfSubtask());
+                if (noMoreSplit) {
+                    // signal to the source that we have reached the end of the data.
+                    log.info("Closed the bounded amazonDynamodb source");
+                    context.signalNoMoreElement();
+                    Thread.sleep(2000L);
+                }
             }
-            lastKeyEvaluated = scan.lastEvaluatedKey();
-        } while (lastKeyEvaluated != null && !lastKeyEvaluated.isEmpty());
-        context.signalNoMoreElement();
+            if (Objects.nonNull(split)) {
+                read(split, output);
+            }
+        }
     }
+
+    @Override
+    public List<AmazonDynamoDBSourceSplit> snapshotState(long checkpointId) {
+        return new ArrayList<>(pendingSplits);
+    }
+
+    @Override
+    public void addSplits(List<AmazonDynamoDBSourceSplit> splits) {
+        this.pendingSplits.addAll(splits);
+    }
+
+    @Override
+    public void handleNoMoreSplits() {
+        log.info("Reader [{}] received noMoreSplit event.", context.getIndexOfSubtask());
+        noMoreSplit = true;
+    }
+
+    private void read(AmazonDynamoDBSourceSplit split, Collector<SeaTunnelRow> output) {
+        ScanIterable scan;
+        ScanRequest scanRequest =
+                ScanRequest.builder()
+                        .tableName(amazondynamodbSourceOptions.getTable())
+                        .limit(split.getItemCount())
+                        .segment(split.getSplitId())
+                        .totalSegments(split.getTotalSegments())
+                        .build();
+        scan = dynamoDbClient.scanPaginator(scanRequest);
+        do {
+
+            scan.items()
+                    .forEach(
+                            item -> {
+                                output.collect(seaTunnelRowDeserializer.deserialize(item));
+                            });
+
+        } while (scan.iterator().hasNext() && !noMoreSplit);
+    }
+
+    @Override
+    public void notifyCheckpointComplete(long checkpointId) {}
 }
