@@ -114,9 +114,9 @@ public abstract class AbstractJdbcSourceChunkSplitter implements JdbcSourceChunk
     }
 
     private List<ChunkRange> splitTableIntoChunks(
-            JdbcConnection jdbc, TableId tableId, Column splitColumn) throws SQLException {
+            JdbcConnection jdbc, TableId tableId, Column splitColumn) throws Exception {
         final String splitColumnName = splitColumn.name();
-        final Object[] minMax = queryMinMax(jdbc, tableId, splitColumnName);
+        final Object[] minMax = queryMinMax(jdbc, tableId, splitColumn);
         final Object min = minMax[0];
         final Object max = minMax[1];
         if (min == null || max == null || min.equals(max)) {
@@ -177,8 +177,7 @@ public abstract class AbstractJdbcSourceChunkSplitter implements JdbcSourceChunk
                             tableId,
                             inverseSamplingRate);
                     Object[] sample =
-                            sampleDataFromColumn(
-                                    jdbc, tableId, splitColumnName, inverseSamplingRate);
+                            sampleDataFromColumn(jdbc, tableId, splitColumn, inverseSamplingRate);
                     log.info(
                             "Sample data from table {} end, the sample size is {}",
                             tableId,
@@ -186,11 +185,10 @@ public abstract class AbstractJdbcSourceChunkSplitter implements JdbcSourceChunk
                     return efficientShardingThroughSampling(
                             tableId, sample, approximateRowCnt, shardCount);
                 }
-                return splitUnevenlySizedChunks(
-                        jdbc, tableId, splitColumnName, min, max, chunkSize);
+                return splitUnevenlySizedChunks(jdbc, tableId, splitColumn, min, max, chunkSize);
             }
         } else {
-            return splitUnevenlySizedChunks(jdbc, tableId, splitColumnName, min, max, chunkSize);
+            return splitUnevenlySizedChunks(jdbc, tableId, splitColumn, min, max, chunkSize);
         }
     }
 
@@ -198,7 +196,7 @@ public abstract class AbstractJdbcSourceChunkSplitter implements JdbcSourceChunk
     protected List<ChunkRange> splitUnevenlySizedChunks(
             JdbcConnection jdbc,
             TableId tableId,
-            String splitColumnName,
+            Column splitColumn,
             Object min,
             Object max,
             int chunkSize)
@@ -207,7 +205,7 @@ public abstract class AbstractJdbcSourceChunkSplitter implements JdbcSourceChunk
                 "Use unevenly-sized chunks for table {}, the chunk size is {}", tableId, chunkSize);
         final List<ChunkRange> splits = new ArrayList<>();
         Object chunkStart = null;
-        Object chunkEnd = nextChunkEnd(jdbc, min, tableId, splitColumnName, max, chunkSize);
+        Object chunkEnd = nextChunkEnd(jdbc, min, tableId, splitColumn, max, chunkSize);
         int count = 0;
         while (chunkEnd != null && ObjectCompare(chunkEnd, max) <= 0) {
             // we start from [null, min + chunk_size) and avoid [null, min)
@@ -215,7 +213,7 @@ public abstract class AbstractJdbcSourceChunkSplitter implements JdbcSourceChunk
             // may sleep a while to avoid DDOS on MySQL server
             maySleep(count++, tableId);
             chunkStart = chunkEnd;
-            chunkEnd = nextChunkEnd(jdbc, chunkEnd, tableId, splitColumnName, max, chunkSize);
+            chunkEnd = nextChunkEnd(jdbc, chunkEnd, tableId, splitColumn, max, chunkSize);
         }
         // add the ending split
         splits.add(ChunkRange.of(chunkStart, null));
@@ -226,17 +224,17 @@ public abstract class AbstractJdbcSourceChunkSplitter implements JdbcSourceChunk
             JdbcConnection jdbc,
             Object previousChunkEnd,
             TableId tableId,
-            String splitColumnName,
+            Column splitColumn,
             Object max,
             int chunkSize)
             throws SQLException {
         // chunk end might be null when max values are removed
         Object chunkEnd =
-                queryNextChunkMax(jdbc, tableId, splitColumnName, chunkSize, previousChunkEnd);
+                queryNextChunkMax(jdbc, tableId, splitColumn, chunkSize, previousChunkEnd);
         if (Objects.equals(previousChunkEnd, chunkEnd)) {
             // we don't allow equal chunk start and end,
             // should query the next one larger than chunkEnd
-            chunkEnd = queryMin(jdbc, tableId, splitColumnName, chunkEnd);
+            chunkEnd = queryMin(jdbc, tableId, splitColumn, chunkEnd);
         }
         if (ObjectCompare(chunkEnd, max) >= 0) {
             return null;
