@@ -23,8 +23,8 @@ import org.slf4j.LoggerFactory;
 import io.debezium.connector.sqlserver.SqlServerConnectorConfig.SnapshotMode;
 import io.debezium.pipeline.ErrorHandler;
 import io.debezium.pipeline.EventDispatcher;
-import io.debezium.pipeline.source.spi.ChangeEventSource;
 import io.debezium.pipeline.source.spi.StreamingChangeEventSource;
+import io.debezium.relational.ChangeTable;
 import io.debezium.relational.Table;
 import io.debezium.relational.TableId;
 import io.debezium.schema.SchemaChangeEvent.SchemaChangeEventType;
@@ -37,11 +37,11 @@ import java.time.Duration;
 import java.time.Instant;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.PriorityQueue;
 import java.util.Queue;
-import java.util.Set;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicReference;
 import java.util.regex.Matcher;
@@ -49,8 +49,12 @@ import java.util.regex.Pattern;
 import java.util.stream.Collectors;
 
 /**
- * A {@link StreamingChangeEventSource} based on SQL Server change data capture functionality. A
- * main loop polls database DDL change and change data tables and turns them into change events.
+ * Copied from Debezium project(1.9.8.final) to add method {@link
+ * SqlServerStreamingChangeEventSource#afterHandleLsn(SqlServerPartition, Map<String, ?>)}. Also
+ * implemented {@link SqlServerStreamingChangeEventSource#execute(ChangeEventSourceContext,
+ * SqlServerPartition, SqlServerOffsetContext)}. A {@link StreamingChangeEventSource} based on SQL
+ * Server change data capture functionality. A main loop polls database DDL change and change data
+ * tables and turns them into change events.
  *
  * <p>The connector uses CDC functionality of SQL Server that is implemented as as a process that
  * monitors source table and write changes from the table into the change table.
@@ -68,10 +72,10 @@ import java.util.stream.Collectors;
  * old one. Then the change table is switched and streaming is executed from the new one.
  */
 public class SqlServerStreamingChangeEventSource
-        implements StreamingChangeEventSource<SqlServerOffsetContext> {
+        implements StreamingChangeEventSource<SqlServerPartition, SqlServerOffsetContext> {
 
     private static final Pattern MISSING_CDC_FUNCTION_CHANGES_ERROR =
-            Pattern.compile("Invalid object name 'cdc.fn_cdc_get_all_changes_(.*)'\\.");
+            Pattern.compile("Invalid object name '(.*)\\.cdc.fn_cdc_get_all_changes_(.*)'\\.");
 
     private static final Logger LOGGER =
             LoggerFactory.getLogger(SqlServerStreamingChangeEventSource.class);
@@ -83,15 +87,15 @@ public class SqlServerStreamingChangeEventSource
     private final SqlServerConnection dataConnection;
 
     /**
-     * A separate connection for retrieving timestamps; without it, adaptive buffering will not
-     * work.
+     * A separate connection for retrieving details of the schema changes; without it, adaptive
+     * buffering will not work.
      *
      * @link
      *     https://docs.microsoft.com/en-us/sql/connect/jdbc/using-adaptive-buffering?view=sql-server-2017#guidelines-for-using-adaptive-buffering
      */
     private final SqlServerConnection metadataConnection;
 
-    private final EventDispatcher<TableId> dispatcher;
+    private final EventDispatcher<SqlServerPartition, TableId> dispatcher;
     private final ErrorHandler errorHandler;
     private final Clock clock;
     private final SqlServerDatabaseSchema schema;
@@ -99,12 +103,14 @@ public class SqlServerStreamingChangeEventSource
     private final SqlServerConnectorConfig connectorConfig;
 
     private final ElapsedTimeStrategy pauseBetweenCommits;
+    private final Map<SqlServerPartition, SqlServerStreamingExecutionContext>
+            streamingExecutionContexts;
 
     public SqlServerStreamingChangeEventSource(
             SqlServerConnectorConfig connectorConfig,
             SqlServerConnection dataConnection,
             SqlServerConnection metadataConnection,
-            EventDispatcher<TableId> dispatcher,
+            EventDispatcher<SqlServerPartition, TableId> dispatcher,
             ErrorHandler errorHandler,
             Clock clock,
             SqlServerDatabaseSchema schema) {
@@ -127,77 +133,120 @@ public class SqlServerStreamingChangeEventSource
                                 ? DEFAULT_INTERVAL_BETWEEN_COMMITS.toMillis()
                                 : intervalBetweenCommitsBasedOnPoll.toMillis());
         this.pauseBetweenCommits.hasElapsed();
+        this.streamingExecutionContexts = new HashMap<>();
     }
 
     @Override
     public void execute(
-            ChangeEventSource.ChangeEventSourceContext context,
+            ChangeEventSourceContext context,
+            SqlServerPartition partition,
+            SqlServerOffsetContext offsetContext)
+            throws InterruptedException {
+        final Metronome metronome = Metronome.sleeper(pollInterval, clock);
+
+        LOGGER.info("Starting streaming");
+
+        while (context.isRunning()) {
+            boolean streamedEvents = executeIteration(context, partition, offsetContext);
+
+            if (!streamedEvents) {
+                metronome.pause();
+            }
+        }
+
+        LOGGER.info("Finished streaming");
+    }
+
+    @Override
+    public boolean executeIteration(
+            ChangeEventSourceContext context,
+            SqlServerPartition partition,
             SqlServerOffsetContext offsetContext)
             throws InterruptedException {
         if (connectorConfig.getSnapshotMode().equals(SnapshotMode.INITIAL_ONLY)) {
             LOGGER.info("Streaming is not enabled in current configuration");
-            return;
+            return false;
         }
 
-        final Metronome metronome = Metronome.sleeper(pollInterval, clock);
-        final Queue<SqlServerChangeTable> schemaChangeCheckpoints =
-                new PriorityQueue<>((x, y) -> x.getStopLsn().compareTo(y.getStopLsn()));
-        try {
-            final AtomicReference<SqlServerChangeTable[]> tablesSlot =
-                    new AtomicReference<SqlServerChangeTable[]>(getCdcTablesToQuery(offsetContext));
+        final String databaseName = partition.getDatabaseName();
 
+        try {
+            final SqlServerStreamingExecutionContext streamingExecutionContext =
+                    streamingExecutionContexts.getOrDefault(
+                            partition,
+                            new SqlServerStreamingExecutionContext(
+                                    new PriorityQueue<>(
+                                            (x, y) -> x.getStopLsn().compareTo(y.getStopLsn())),
+                                    new AtomicReference<>(),
+                                    offsetContext.getChangePosition(),
+                                    new AtomicBoolean(false),
+                                    // LSN should be increased for the first run only immediately
+                                    // after snapshot completion
+                                    // otherwise we might skip an incomplete transaction after
+                                    // restart
+                                    offsetContext.isSnapshotCompleted()));
+
+            if (!streamingExecutionContexts.containsKey(partition)) {
+                streamingExecutionContexts.put(partition, streamingExecutionContext);
+                LOGGER.info(
+                        "Last position recorded in offsets is {}[{}]",
+                        offsetContext.getChangePosition(),
+                        offsetContext.getEventSerialNo());
+            }
+
+            final Queue<SqlServerChangeTable> schemaChangeCheckpoints =
+                    streamingExecutionContext.getSchemaChangeCheckpoints();
+            final AtomicReference<SqlServerChangeTable[]> tablesSlot =
+                    streamingExecutionContext.getTablesSlot();
             final TxLogPosition lastProcessedPositionOnStart = offsetContext.getChangePosition();
             final long lastProcessedEventSerialNoOnStart = offsetContext.getEventSerialNo();
-            LOGGER.info(
-                    "Last position recorded in offsets is {}[{}]",
-                    lastProcessedPositionOnStart,
-                    lastProcessedEventSerialNoOnStart);
-            final AtomicBoolean changesStoppedBeingMonotonic = new AtomicBoolean(false);
+            final AtomicBoolean changesStoppedBeingMonotonic =
+                    streamingExecutionContext.getChangesStoppedBeingMonotonic();
             final int maxTransactionsPerIteration =
                     connectorConfig.getMaxTransactionsPerIteration();
 
-            TxLogPosition lastProcessedPosition = lastProcessedPositionOnStart;
+            TxLogPosition lastProcessedPosition =
+                    streamingExecutionContext.getLastProcessedPosition();
 
-            // LSN should be increased for the first run only immediately after snapshot completion
-            // otherwise we might skip an incomplete transaction after restart
-            boolean shouldIncreaseFromLsn = offsetContext.isSnapshotCompleted();
-            while (context.isRunning()) {
+            if (context.isRunning()) {
                 commitTransaction();
-                afterHandleLsn(offsetContext);
                 final Lsn toLsn =
                         getToLsn(
-                                dataConnection, lastProcessedPosition, maxTransactionsPerIteration);
+                                dataConnection,
+                                databaseName,
+                                lastProcessedPosition,
+                                maxTransactionsPerIteration);
 
                 // Shouldn't happen if the agent is running, but it is better to guard against such
                 // situation
                 if (!toLsn.isAvailable()) {
                     LOGGER.warn(
                             "No maximum LSN recorded in the database; please ensure that the SQL Server Agent is running");
-                    metronome.pause();
-                    continue;
+                    return false;
                 }
                 // There is no change in the database
                 if (toLsn.compareTo(lastProcessedPosition.getCommitLsn()) <= 0
-                        && shouldIncreaseFromLsn) {
+                        && streamingExecutionContext.getShouldIncreaseFromLsn()) {
                     LOGGER.debug("No change in the database");
-                    metronome.pause();
-                    dispatcher.dispatchHeartbeatEvent(offsetContext);
-                    continue;
+                    return false;
                 }
 
                 // Reading interval is inclusive so we need to move LSN forward but not for first
                 // run as TX might not be streamed completely
                 final Lsn fromLsn =
-                        lastProcessedPosition.getCommitLsn().isAvailable() && shouldIncreaseFromLsn
-                                ? dataConnection.incrementLsn(lastProcessedPosition.getCommitLsn())
+                        lastProcessedPosition.getCommitLsn().isAvailable()
+                                        && streamingExecutionContext.getShouldIncreaseFromLsn()
+                                ? dataConnection.incrementLsn(
+                                        databaseName, lastProcessedPosition.getCommitLsn())
                                 : lastProcessedPosition.getCommitLsn();
-                shouldIncreaseFromLsn = true;
+                streamingExecutionContext.setShouldIncreaseFromLsn(true);
 
                 while (!schemaChangeCheckpoints.isEmpty()) {
-                    migrateTable(schemaChangeCheckpoints, offsetContext);
+                    migrateTable(partition, schemaChangeCheckpoints, offsetContext);
                 }
-                if (!dataConnection.listOfNewChangeTables(fromLsn, toLsn).isEmpty()) {
-                    final SqlServerChangeTable[] tables = getCdcTablesToQuery(offsetContext);
+                if (!dataConnection.getNewChangeTables(databaseName, fromLsn, toLsn).isEmpty()) {
+                    final SqlServerChangeTable[] tables =
+                            getChangeTablesToQuery(partition, offsetContext, toLsn);
                     tablesSlot.set(tables);
                     for (SqlServerChangeTable table : tables) {
                         if (table.getStartLsn().isBetween(fromLsn, toLsn)) {
@@ -206,8 +255,12 @@ public class SqlServerStreamingChangeEventSource
                         }
                     }
                 }
+                if (tablesSlot.get() == null) {
+                    tablesSlot.set(getChangeTablesToQuery(partition, offsetContext, toLsn));
+                }
                 try {
                     dataConnection.getChangesForTables(
+                            databaseName,
                             tablesSlot.get(),
                             fromLsn,
                             toLsn,
@@ -337,7 +390,10 @@ public class SqlServerStreamingChangeEventSource
                                                                         .peek()
                                                                         .getStartLsn())
                                                 >= 0) {
-                                            migrateTable(schemaChangeCheckpoints, offsetContext);
+                                            migrateTable(
+                                                    partition,
+                                                    schemaChangeCheckpoints,
+                                                    offsetContext);
                                         }
                                     }
                                     final TableId tableId =
@@ -384,13 +440,14 @@ public class SqlServerStreamingChangeEventSource
                                             connectorConfig
                                                     .getSourceTimestampMode()
                                                     .getTimestamp(
-                                                            metadataConnection,
                                                             clock,
                                                             tableWithSmallestLsn.getResultSet()));
 
                                     dispatcher.dispatchDataChangeEvent(
+                                            partition,
                                             tableId,
                                             new SqlServerChangeRecordEmitter(
+                                                    partition,
                                                     offsetContext,
                                                     operation,
                                                     data,
@@ -399,16 +456,22 @@ public class SqlServerStreamingChangeEventSource
                                     tableWithSmallestLsn.next();
                                 }
                             });
-                    lastProcessedPosition = TxLogPosition.valueOf(toLsn);
+                    streamingExecutionContext.setLastProcessedPosition(
+                            TxLogPosition.valueOf(toLsn));
                     // Terminate the transaction otherwise CDC could not be disabled for tables
                     dataConnection.rollback();
+                    // Determine whether to continue streaming in sqlserver cdc snapshot phase
+                    afterHandleLsn(partition, offsetContext.getOffset());
                 } catch (SQLException e) {
-                    tablesSlot.set(processErrorFromChangeTableQuery(e, tablesSlot.get()));
+                    tablesSlot.set(
+                            processErrorFromChangeTableQuery(databaseName, e, tablesSlot.get()));
                 }
             }
         } catch (Exception e) {
             errorHandler.setProducerThrowable(e);
         }
+
+        return true;
     }
 
     private void commitTransaction() throws SQLException {
@@ -419,47 +482,63 @@ public class SqlServerStreamingChangeEventSource
         // TempDB
         if (connectorConfig.isReadOnlyDatabaseConnection() || pauseBetweenCommits.hasElapsed()) {
             dataConnection.commit();
+            metadataConnection.commit();
         }
     }
 
     private void migrateTable(
+            SqlServerPartition partition,
             final Queue<SqlServerChangeTable> schemaChangeCheckpoints,
             SqlServerOffsetContext offsetContext)
             throws InterruptedException, SQLException {
         final SqlServerChangeTable newTable = schemaChangeCheckpoints.poll();
         LOGGER.info("Migrating schema to {}", newTable);
-        Table tableSchema = metadataConnection.getTableSchemaFromTable(newTable);
+        Table oldTableSchema = schema.tableFor(newTable.getSourceTableId());
+        Table tableSchema =
+                metadataConnection.getTableSchemaFromTable(partition.getDatabaseName(), newTable);
+        if (oldTableSchema.equals(tableSchema)) {
+            LOGGER.info("Migration skipped, no table schema changes detected.");
+            return;
+        }
         dispatcher.dispatchSchemaChangeEvent(
+                partition,
                 newTable.getSourceTableId(),
                 new SqlServerSchemaChangeEventEmitter(
-                        offsetContext, newTable, tableSchema, SchemaChangeEventType.ALTER));
+                        partition,
+                        offsetContext,
+                        newTable,
+                        tableSchema,
+                        SchemaChangeEventType.ALTER));
         newTable.setSourceTable(tableSchema);
     }
 
     private SqlServerChangeTable[] processErrorFromChangeTableQuery(
-            SQLException exception, SqlServerChangeTable[] currentChangeTables) throws Exception {
+            String databaseName, SQLException exception, SqlServerChangeTable[] currentChangeTables)
+            throws Exception {
         final Matcher m = MISSING_CDC_FUNCTION_CHANGES_ERROR.matcher(exception.getMessage());
-        if (m.matches()) {
-            final String captureName = m.group(1);
+        if (m.matches() && m.group(1).equals(databaseName)) {
+            final String captureName = m.group(2);
             LOGGER.info("Table is no longer captured with capture instance {}", captureName);
-            return Arrays.asList(currentChangeTables).stream()
+            return Arrays.stream(currentChangeTables)
                     .filter(x -> !x.getCaptureInstance().equals(captureName))
-                    .collect(Collectors.toList())
-                    .toArray(new SqlServerChangeTable[0]);
+                    .toArray(SqlServerChangeTable[]::new);
         }
         throw exception;
     }
 
-    private SqlServerChangeTable[] getCdcTablesToQuery(SqlServerOffsetContext offsetContext)
+    private SqlServerChangeTable[] getChangeTablesToQuery(
+            SqlServerPartition partition, SqlServerOffsetContext offsetContext, Lsn toLsn)
             throws SQLException, InterruptedException {
-        final Set<SqlServerChangeTable> cdcEnabledTables = dataConnection.listOfChangeTables();
-        if (cdcEnabledTables.isEmpty()) {
+        final String databaseName = partition.getDatabaseName();
+        final List<SqlServerChangeTable> changeTables =
+                dataConnection.getChangeTables(databaseName, toLsn);
+        if (changeTables.isEmpty()) {
             LOGGER.warn(
                     "No table has enabled CDC or security constraints prevents getting the list of change tables");
         }
 
-        final Map<TableId, List<SqlServerChangeTable>> includeListCdcEnabledTables =
-                cdcEnabledTables.stream()
+        final Map<TableId, List<SqlServerChangeTable>> includeListChangeTables =
+                changeTables.stream()
                         .filter(
                                 changeTable -> {
                                     if (connectorConfig
@@ -474,15 +553,15 @@ public class SqlServerStreamingChangeEventSource
                                         return false;
                                     }
                                 })
-                        .collect(Collectors.groupingBy(x -> x.getSourceTableId()));
+                        .collect(Collectors.groupingBy(ChangeTable::getSourceTableId));
 
-        if (includeListCdcEnabledTables.isEmpty()) {
+        if (includeListChangeTables.isEmpty()) {
             LOGGER.warn(
                     "No whitelisted table has enabled CDC, whitelisted table list does not contain any table with CDC enabled or no table match the white/blacklist filter(s)");
         }
 
         final List<SqlServerChangeTable> tables = new ArrayList<>();
-        for (List<SqlServerChangeTable> captures : includeListCdcEnabledTables.values()) {
+        for (List<SqlServerChangeTable> captures : includeListChangeTables.values()) {
             SqlServerChangeTable currentTable = captures.get(0);
             if (captures.size() > 1) {
                 SqlServerChangeTable futureTable;
@@ -493,7 +572,8 @@ public class SqlServerStreamingChangeEventSource
                     futureTable = captures.get(0);
                 }
                 currentTable.setStopLsn(futureTable.getStartLsn());
-                futureTable.setSourceTable(dataConnection.getTableSchemaFromTable(futureTable));
+                futureTable.setSourceTable(
+                        dataConnection.getTableSchemaFromTable(databaseName, futureTable));
                 tables.add(futureTable);
                 LOGGER.info(
                         "Multiple capture instances present for the same table: {} and {}",
@@ -511,11 +591,13 @@ public class SqlServerStreamingChangeEventSource
                 // timestamp is used
                 offsetContext.event(currentTable.getSourceTableId(), Instant.now());
                 dispatcher.dispatchSchemaChangeEvent(
+                        partition,
                         currentTable.getSourceTableId(),
                         new SqlServerSchemaChangeEventEmitter(
+                                partition,
                                 offsetContext,
                                 currentTable,
-                                dataConnection.getTableSchemaFromTable(currentTable),
+                                dataConnection.getTableSchemaFromTable(databaseName, currentTable),
                                 SchemaChangeEventType.CREATE));
             }
 
@@ -535,25 +617,28 @@ public class SqlServerStreamingChangeEventSource
      */
     private Lsn getToLsn(
             SqlServerConnection connection,
+            String databaseName,
             TxLogPosition lastProcessedPosition,
             int maxTransactionsPerIteration)
             throws SQLException {
 
         if (maxTransactionsPerIteration == 0) {
-            return connection.getMaxTransactionLsn();
+            return connection.getMaxTransactionLsn(databaseName);
         }
 
         final Lsn fromLsn = lastProcessedPosition.getCommitLsn();
 
         if (!fromLsn.isAvailable()) {
-            return connection.getNthTransactionLsnFromBeginning(maxTransactionsPerIteration);
+            return connection.getNthTransactionLsnFromBeginning(
+                    databaseName, maxTransactionsPerIteration);
         }
 
-        return connection.getNthTransactionLsnFromLast(fromLsn, maxTransactionsPerIteration);
+        return connection.getNthTransactionLsnFromLast(
+                databaseName, fromLsn, maxTransactionsPerIteration);
     }
 
     /** expose control to the user to stop the connector. */
-    protected void afterHandleLsn(SqlServerOffsetContext offsetContext) {
+    protected void afterHandleLsn(SqlServerPartition partition, Map<String, ?> offset) {
         // do nothing
     }
 }
