@@ -17,22 +17,20 @@
 
 package org.apache.seatunnel.connectors.doris.util;
 
-import org.apache.seatunnel.api.sink.SaveModeConstants;
+import org.apache.seatunnel.api.sink.SaveModePlaceHolder;
 import org.apache.seatunnel.api.table.catalog.CatalogTable;
 import org.apache.seatunnel.api.table.catalog.Column;
 import org.apache.seatunnel.api.table.catalog.TablePath;
 import org.apache.seatunnel.api.table.catalog.TableSchema;
-import org.apache.seatunnel.api.table.catalog.exception.CatalogException;
-import org.apache.seatunnel.api.table.type.ArrayType;
-import org.apache.seatunnel.api.table.type.BasicType;
-import org.apache.seatunnel.api.table.type.DecimalType;
-import org.apache.seatunnel.api.table.type.LocalTimeType;
-import org.apache.seatunnel.api.table.type.SeaTunnelDataType;
+import org.apache.seatunnel.api.table.converter.BasicTypeDefine;
+import org.apache.seatunnel.api.table.converter.TypeConverter;
+import org.apache.seatunnel.connectors.doris.config.DorisOptions;
+import org.apache.seatunnel.connectors.seatunnel.common.sql.template.SqlTemplate;
 
 import org.apache.commons.lang3.StringUtils;
 
-import java.sql.ResultSet;
-import java.sql.SQLException;
+import lombok.extern.slf4j.Slf4j;
+
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.Comparator;
@@ -43,6 +41,7 @@ import java.util.stream.Collectors;
 
 import static com.google.common.base.Preconditions.checkNotNull;
 
+@Slf4j
 public class DorisCatalogUtil {
 
     public static final String ALL_DATABASES_QUERY =
@@ -64,12 +63,14 @@ public class DorisCatalogUtil {
                     + "ORDER BY TABLE_NAME";
 
     public static final String TABLE_SCHEMA_QUERY =
-            "SELECT COLUMN_NAME,ORDINAL_POSITION,COLUMN_DEFAULT,IS_NULLABLE,COLUMN_TYPE,COLUMN_SIZE,"
-                    + "COLUMN_KEY,NUMERIC_PRECISION,NUMERIC_SCALE,COLUMN_COMMENT "
+            "SELECT * "
                     + "FROM information_schema.columns "
                     + "WHERE TABLE_CATALOG = 'internal' AND TABLE_SCHEMA = ? AND TABLE_NAME = ? "
                     + "ORDER BY ORDINAL_POSITION";
 
+    public static final String QUERY_DORIS_VERSION_QUERY =
+            "show variables like \"version_comment\";";
+
     public static String randomFrontEndHost(String[] frontEndNodes) {
         if (frontEndNodes.length == 1) {
             return frontEndNodes[0].split(":")[0];
@@ -102,20 +103,24 @@ public class DorisCatalogUtil {
     /**
      * @param createTableTemplate create table template
      * @param catalogTable catalog table
+     * @param typeConverter
      * @return create table stmt
      */
     public static String getCreateTableStatement(
-            String createTableTemplate, TablePath tablePath, CatalogTable catalogTable) {
+            String createTableTemplate,
+            TablePath tablePath,
+            CatalogTable catalogTable,
+            TypeConverter<BasicTypeDefine> typeConverter) {
 
         String template = createTableTemplate;
         TableSchema tableSchema = catalogTable.getTableSchema();
 
         String primaryKey = "";
         if (tableSchema.getPrimaryKey() != null) {
-            primaryKey =
-                    tableSchema.getPrimaryKey().getColumnNames().stream()
-                            .map(r -> "`" + r + "`")
-                            .collect(Collectors.joining(","));
+            List<String> fields = Arrays.asList(catalogTable.getTableSchema().getFieldNames());
+            List<String> keys = tableSchema.getPrimaryKey().getColumnNames();
+            keys.sort(Comparator.comparingInt(fields::indexOf));
+            primaryKey = keys.stream().map(r -> "`" + r + "`").collect(Collectors.joining(","));
         }
         String uniqueKey = "";
         if (!tableSchema.getConstraintKeys().isEmpty()) {
@@ -125,38 +130,88 @@ public class DorisCatalogUtil {
                             .map(r -> "`" + r.getColumnName() + "`")
                             .collect(Collectors.joining(","));
         }
+
+        // dup key
+        String dupKey = "";
+        if (catalogTable.getOptions() != null
+                && StringUtils.isNotBlank(
+                        catalogTable
+                                .getOptions()
+                                .get(
+                                        SaveModePlaceHolder.ROWTYPE_DUPLICATE_KEY
+                                                .getPlaceHolderKey()))) {
+            String dupKeyColumns =
+                    catalogTable
+                            .getOptions()
+                            .get(SaveModePlaceHolder.ROWTYPE_DUPLICATE_KEY.getPlaceHolderKey());
+            dupKey =
+                    Arrays.stream(dupKeyColumns.split(","))
+                            .map(r -> "`" + r + "`")
+                            .collect(Collectors.joining(","));
+        }
+
+        SqlTemplate.canHandledByTemplateWithPlaceholder(
+                template,
+                SaveModePlaceHolder.ROWTYPE_PRIMARY_KEY.getPlaceHolder(),
+                primaryKey,
+                tablePath.getFullName(),
+                DorisOptions.SAVE_MODE_CREATE_TEMPLATE.key());
         template =
                 template.replaceAll(
-                        String.format("\\$\\{%s\\}", SaveModeConstants.ROWTYPE_PRIMARY_KEY),
+                        SaveModePlaceHolder.ROWTYPE_PRIMARY_KEY.getReplacePlaceHolder(),
                         primaryKey);
+        SqlTemplate.canHandledByTemplateWithPlaceholder(
+                template,
+                SaveModePlaceHolder.ROWTYPE_UNIQUE_KEY.getPlaceHolder(),
+                uniqueKey,
+                tablePath.getFullName(),
+                DorisOptions.SAVE_MODE_CREATE_TEMPLATE.key());
         template =
                 template.replaceAll(
-                        String.format("\\$\\{%s\\}", SaveModeConstants.ROWTYPE_UNIQUE_KEY),
-                        uniqueKey);
+                        SaveModePlaceHolder.ROWTYPE_UNIQUE_KEY.getReplacePlaceHolder(), uniqueKey);
+        SqlTemplate.canHandledByTemplateWithPlaceholder(
+                template,
+                SaveModePlaceHolder.ROWTYPE_DUPLICATE_KEY.getPlaceHolder(),
+                dupKey,
+                tablePath.getFullName(),
+                DorisOptions.SAVE_MODE_CREATE_TEMPLATE.key());
+        template =
+                template.replaceAll(
+                        SaveModePlaceHolder.ROWTYPE_DUPLICATE_KEY.getReplacePlaceHolder(), dupKey);
         Map<String, CreateTableParser.ColumnInfo> columnInTemplate =
                 CreateTableParser.getColumnList(template);
-        template = mergeColumnInTemplate(columnInTemplate, tableSchema, template);
+        template = mergeColumnInTemplate(columnInTemplate, tableSchema, template, typeConverter);
 
         String rowTypeFields =
                 tableSchema.getColumns().stream()
                         .filter(column -> !columnInTemplate.containsKey(column.getName()))
-                        .map(DorisCatalogUtil::columnToDorisType)
+                        .map(x -> DorisCatalogUtil.columnToDorisType(x, typeConverter))
                         .collect(Collectors.joining(",\n"));
+
+        if (template.contains(SaveModePlaceHolder.TABLE_NAME.getPlaceHolder())) {
+            // TODO: Remove this compatibility config
+            template =
+                    template.replaceAll(
+                            SaveModePlaceHolder.TABLE_NAME.getReplacePlaceHolder(),
+                            tablePath.getTableName());
+            log.warn(
+                    "The variable placeholder `${table_name}` has been marked as deprecated and will be removed soon, please use `${table}`");
+        }
+
         return template.replaceAll(
-                        String.format("\\$\\{%s\\}", SaveModeConstants.DATABASE),
+                        SaveModePlaceHolder.DATABASE.getReplacePlaceHolder(),
                         tablePath.getDatabaseName())
                 .replaceAll(
-                        String.format("\\$\\{%s\\}", SaveModeConstants.TABLE_NAME),
-                        tablePath.getTableName())
+                        SaveModePlaceHolder.TABLE.getReplacePlaceHolder(), tablePath.getTableName())
                 .replaceAll(
-                        String.format("\\$\\{%s\\}", SaveModeConstants.ROWTYPE_FIELDS),
-                        rowTypeFields);
+                        SaveModePlaceHolder.ROWTYPE_FIELDS.getReplacePlaceHolder(), rowTypeFields);
     }
 
     private static String mergeColumnInTemplate(
             Map<String, CreateTableParser.ColumnInfo> columnInTemplate,
             TableSchema tableSchema,
-            String template) {
+            String template,
+            TypeConverter<BasicTypeDefine> typeConverter) {
         int offset = 0;
         Map<String, Column> columnMap =
                 tableSchema.getColumns().stream()
@@ -172,7 +227,7 @@ public class DorisCatalogUtil {
             if (StringUtils.isEmpty(columnInfo.getInfo())) {
                 if (columnMap.containsKey(col)) {
                     Column column = columnMap.get(col);
-                    String newCol = columnToDorisType(column);
+                    String newCol = columnToDorisType(column, typeConverter);
                     String prefix = template.substring(0, columnInfo.getStartIndex() + offset);
                     String suffix = template.substring(offset + columnInfo.getEndIndex());
                     if (prefix.endsWith("`")) {
@@ -193,120 +248,13 @@ public class DorisCatalogUtil {
         return template;
     }
 
-    private static String columnToDorisType(Column column) {
+    private static String columnToDorisType(
+            Column column, TypeConverter<BasicTypeDefine> typeConverter) {
         checkNotNull(column, "The column is required.");
         return String.format(
                 "`%s` %s %s ",
                 column.getName(),
-                fromSeaTunnelType(
-                        column.getDataType(),
-                        column.getColumnLength() == null ? 0 : column.getColumnLength()),
+                typeConverter.reconvert(column).getColumnType(),
                 column.isNullable() ? "NULL" : "NOT NULL");
     }
-
-    public static SeaTunnelDataType<?> fromDorisType(ResultSet rs) throws SQLException {
-
-        String type = rs.getString(5).toUpperCase();
-        int idx = type.indexOf("(");
-        int idx2 = type.indexOf("<");
-        if (idx != -1) {
-            type = type.substring(0, idx);
-        }
-        if (idx2 != -1) {
-            type = type.substring(0, idx2);
-        }
-
-        switch (type) {
-            case "NULL_TYPE":
-                return BasicType.VOID_TYPE;
-            case "BOOLEAN":
-                return BasicType.BOOLEAN_TYPE;
-            case "TINYINT":
-            case "SMALLINT":
-                return BasicType.SHORT_TYPE;
-            case "INT":
-                return BasicType.INT_TYPE;
-            case "BIGINT":
-                return BasicType.LONG_TYPE;
-            case "FLOAT":
-                return BasicType.FLOAT_TYPE;
-            case "DOUBLE":
-                return BasicType.DOUBLE_TYPE;
-            case "DATE":
-            case "DATEV2":
-                return LocalTimeType.LOCAL_DATE_TYPE;
-            case "DATETIME":
-            case "DATETIMEV2":
-            case "DATETIMEV3":
-                return LocalTimeType.LOCAL_DATE_TIME_TYPE;
-            case "DECIMAL":
-            case "DECIMALV2":
-            case "DECIMALV3":
-                int precision = rs.getInt(8);
-                int scale = rs.getInt(9);
-                return new DecimalType(precision, scale);
-            case "TIME":
-                return LocalTimeType.LOCAL_TIME_TYPE;
-            case "CHAR":
-            case "LARGEINT":
-            case "VARCHAR":
-            case "JSONB":
-            case "STRING":
-            case "ARRAY":
-            case "MAP":
-            case "STRUCT":
-                return BasicType.STRING_TYPE;
-            default:
-                throw new CatalogException(String.format("Unsupported doris type: %s", type));
-        }
-    }
-
-    private static String fromSeaTunnelType(SeaTunnelDataType<?> dataType, Long columnLength) {
-
-        switch (dataType.getSqlType()) {
-            case STRING:
-                if (columnLength != null && columnLength <= 65533 && columnLength > 0) {
-                    return String.format("VARCHAR(%d)", columnLength);
-                }
-                return "STRING";
-            case BYTES:
-                return "STRING";
-            case NULL:
-                return "NULL_TYPE";
-            case BOOLEAN:
-                return "BOOLEAN";
-            case SMALLINT:
-                return String.format("SMALLINT(%d)", columnLength + 1);
-            case INT:
-                return String.format("INT(%d)", columnLength + 1);
-            case BIGINT:
-                return String.format("BIGINT(%d)", columnLength + 1);
-            case FLOAT:
-                return "FLOAT";
-            case DOUBLE:
-                return "DOUBLE";
-            case DECIMAL:
-                DecimalType decimalType = (DecimalType) dataType;
-                return String.format(
-                        "DECIMALV3(%d,%d)", decimalType.getPrecision(), decimalType.getScale());
-            case TIME:
-                return "VARCHAR(8)";
-            case DATE:
-                return "DATEV2";
-            case TIMESTAMP:
-                return "DATETIME";
-            case ARRAY:
-                return "ARRAY<"
-                        + fromSeaTunnelType(
-                                ((ArrayType<?, ?>) dataType).getElementType(), Long.MAX_VALUE)
-                        + ">";
-            case MAP:
-            case ROW:
-                return "JSONB";
-            case TINYINT:
-                return "TINYINT";
-            default:
-                throw new CatalogException(String.format("Unsupported doris type: %s", dataType));
-        }
-    }
 }
