@@ -208,7 +208,6 @@ public class SFTPFileSystem extends FileSystem {
         return fileStat;
     }
 
-    @SuppressWarnings("checkstyle:MagicNumber")
     private FileStatus getFileStatus(ChannelSftp channel, LsEntry sftpFile, Path parentPath)
             throws IOException {
 
@@ -618,4 +617,10 @@ public class SFTPFileSystem extends FileSystem {
             disconnect(channel);
         }
     }
+
+    @Override
+    public void close() throws IOException {
+        super.close();
+        connectionPool.shutdown();
+    }
 }
