@@ -24,6 +24,7 @@ import org.apache.seatunnel.api.common.SeaTunnelAPIErrorCode;
 import org.apache.seatunnel.api.serialization.DeserializationSchema;
 import org.apache.seatunnel.api.source.Boundedness;
 import org.apache.seatunnel.api.source.SeaTunnelSource;
+import org.apache.seatunnel.api.table.catalog.CatalogTable;
 import org.apache.seatunnel.api.table.catalog.CatalogTableUtil;
 import org.apache.seatunnel.api.table.catalog.schema.TableSchemaOptions;
 import org.apache.seatunnel.api.table.type.SeaTunnelDataType;
@@ -46,6 +47,7 @@ import com.google.auto.service.AutoService;
 public class SheetsSource extends AbstractSingleSplitSource<SeaTunnelRow> {
 
     private SeaTunnelRowType seaTunnelRowType;
+    private CatalogTable catalogTable;
 
     private SheetsParameters sheetsParameters;
 
@@ -75,12 +77,13 @@ public class SheetsSource extends AbstractSingleSplitSource<SeaTunnelRow> {
         }
         this.sheetsParameters = new SheetsParameters().buildWithConfig(pluginConfig);
         if (pluginConfig.hasPath(TableSchemaOptions.SCHEMA.key())) {
-            this.seaTunnelRowType =
-                    CatalogTableUtil.buildWithConfig(pluginConfig).getSeaTunnelRowType();
+            this.catalogTable = CatalogTableUtil.buildWithConfig(pluginConfig);
         } else {
-            this.seaTunnelRowType = CatalogTableUtil.buildSimpleTextSchema();
+            this.catalogTable = CatalogTableUtil.buildSimpleTextTable();
         }
-        this.deserializationSchema = new JsonDeserializationSchema(false, false, seaTunnelRowType);
+
+        this.seaTunnelRowType = catalogTable.getSeaTunnelRowType();
+        this.deserializationSchema = new JsonDeserializationSchema(catalogTable, false, false);
     }
 
     @Override
