@@ -17,22 +17,31 @@
 
 package org.apache.seatunnel.connectors.seatunnel.iceberg.source;
 
+import org.apache.seatunnel.api.configuration.ReadonlyConfig;
 import org.apache.seatunnel.api.configuration.util.OptionRule;
 import org.apache.seatunnel.api.source.SeaTunnelSource;
+import org.apache.seatunnel.api.source.SourceSplit;
+import org.apache.seatunnel.api.table.catalog.CatalogTable;
+import org.apache.seatunnel.api.table.catalog.CatalogTableUtil;
+import org.apache.seatunnel.api.table.catalog.TableIdentifier;
+import org.apache.seatunnel.api.table.catalog.TablePath;
 import org.apache.seatunnel.api.table.catalog.schema.TableSchemaOptions;
+import org.apache.seatunnel.api.table.connector.TableSource;
 import org.apache.seatunnel.api.table.factory.Factory;
 import org.apache.seatunnel.api.table.factory.TableSourceFactory;
+import org.apache.seatunnel.api.table.factory.TableSourceFactoryContext;
+import org.apache.seatunnel.connectors.seatunnel.iceberg.catalog.IcebergCatalog;
+import org.apache.seatunnel.connectors.seatunnel.iceberg.catalog.IcebergCatalogFactory;
+import org.apache.seatunnel.connectors.seatunnel.iceberg.config.CommonConfig;
+import org.apache.seatunnel.connectors.seatunnel.iceberg.config.SinkConfig;
+import org.apache.seatunnel.connectors.seatunnel.iceberg.config.SourceConfig;
 
 import com.google.auto.service.AutoService;
+import lombok.extern.slf4j.Slf4j;
+
+import java.io.Serializable;
 
 import static org.apache.seatunnel.connectors.seatunnel.iceberg.config.CommonConfig.KEY_CASE_SENSITIVE;
-import static org.apache.seatunnel.connectors.seatunnel.iceberg.config.CommonConfig.KEY_CATALOG_NAME;
-import static org.apache.seatunnel.connectors.seatunnel.iceberg.config.CommonConfig.KEY_CATALOG_TYPE;
-import static org.apache.seatunnel.connectors.seatunnel.iceberg.config.CommonConfig.KEY_NAMESPACE;
-import static org.apache.seatunnel.connectors.seatunnel.iceberg.config.CommonConfig.KEY_TABLE;
-import static org.apache.seatunnel.connectors.seatunnel.iceberg.config.CommonConfig.KEY_URI;
-import static org.apache.seatunnel.connectors.seatunnel.iceberg.config.CommonConfig.KEY_WAREHOUSE;
-import static org.apache.seatunnel.connectors.seatunnel.iceberg.config.IcebergCatalogType.HIVE;
 import static org.apache.seatunnel.connectors.seatunnel.iceberg.config.SourceConfig.KEY_END_SNAPSHOT_ID;
 import static org.apache.seatunnel.connectors.seatunnel.iceberg.config.SourceConfig.KEY_START_SNAPSHOT_ID;
 import static org.apache.seatunnel.connectors.seatunnel.iceberg.config.SourceConfig.KEY_START_SNAPSHOT_TIMESTAMP;
@@ -40,6 +49,7 @@ import static org.apache.seatunnel.connectors.seatunnel.iceberg.config.SourceCon
 import static org.apache.seatunnel.connectors.seatunnel.iceberg.config.SourceConfig.KEY_USE_SNAPSHOT_ID;
 import static org.apache.seatunnel.connectors.seatunnel.iceberg.config.SourceConfig.KEY_USE_SNAPSHOT_TIMESTAMP;
 
+@Slf4j
 @AutoService(Factory.class)
 public class IcebergSourceFactory implements TableSourceFactory {
 
@@ -52,8 +62,10 @@ public class IcebergSourceFactory implements TableSourceFactory {
     public OptionRule optionRule() {
         return OptionRule.builder()
                 .required(
-                        KEY_CATALOG_NAME, KEY_CATALOG_TYPE, KEY_WAREHOUSE, KEY_NAMESPACE, KEY_TABLE)
-                .conditional(KEY_CATALOG_TYPE, HIVE, KEY_URI)
+                        CommonConfig.KEY_CATALOG_NAME,
+                        SinkConfig.KEY_NAMESPACE,
+                        SinkConfig.KEY_TABLE,
+                        SinkConfig.CATALOG_PROPS)
                 .optional(
                         TableSchemaOptions.SCHEMA,
                         KEY_CASE_SENSITIVE,
@@ -66,6 +78,32 @@ public class IcebergSourceFactory implements TableSourceFactory {
                 .build();
     }
 
+    @Override
+    public <T, SplitT extends SourceSplit, StateT extends Serializable>
+            TableSource<T, SplitT, StateT> createSource(TableSourceFactoryContext context) {
+        ReadonlyConfig options = context.getOptions();
+        SourceConfig config = new SourceConfig(options);
+        TablePath tablePath = TablePath.of(config.getNamespace(), config.getTable());
+        CatalogTable catalogTable;
+        if (options.get(TableSchemaOptions.SCHEMA) != null) {
+            catalogTable = CatalogTableUtil.buildWithConfig(factoryIdentifier(), options);
+            TableIdentifier tableIdentifier =
+                    TableIdentifier.of(catalogTable.getCatalogName(), tablePath);
+            CatalogTable table = CatalogTable.of(tableIdentifier, catalogTable);
+            return () -> (SeaTunnelSource<T, SplitT, StateT>) new IcebergSource(options, table);
+        } else {
+            // build iceberg catalog
+            IcebergCatalogFactory icebergCatalogFactory = new IcebergCatalogFactory();
+            IcebergCatalog catalog =
+                    (IcebergCatalog)
+                            icebergCatalogFactory.createCatalog(factoryIdentifier(), options);
+            catalog.open();
+            catalogTable = catalog.getTable(tablePath);
+            return () ->
+                    (SeaTunnelSource<T, SplitT, StateT>) new IcebergSource(options, catalogTable);
+        }
+    }
+
     @Override
     public Class<? extends SeaTunnelSource> getSourceClass() {
         return IcebergSource.class;
