@@ -40,8 +40,6 @@ import org.apache.commons.lang3.StringUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.mysql.cj.MysqlType;
-
 import java.io.Serializable;
 import java.sql.Connection;
 import java.sql.PreparedStatement;
@@ -532,8 +530,7 @@ public interface JdbcDialect extends Serializable {
                     "ALTER TABLE %s drop column %s", tableName, quoteIdentifier(oldColumnName));
         }
         TypeConverter<?> typeConverter = ConverterLoader.loadTypeConverter(dialectName());
-        BasicTypeDefine<MysqlType> typeBasicTypeDefine =
-                (BasicTypeDefine<MysqlType>) typeConverter.reconvert(newColumn);
+        BasicTypeDefine typeBasicTypeDefine = (BasicTypeDefine) typeConverter.reconvert(newColumn);
 
         String basicSql = buildAlterTableBasicSql(alterOperation, tableName);
         basicSql =
@@ -616,8 +613,7 @@ public interface JdbcDialect extends Serializable {
      * @param typeBasicTypeDefine type basic type define of new column
      * @return alter table sql with nullable for sink table
      */
-    default String decorateWithNullable(
-            String basicSql, BasicTypeDefine<MysqlType> typeBasicTypeDefine) {
+    default String decorateWithNullable(String basicSql, BasicTypeDefine typeBasicTypeDefine) {
         StringBuilder sql = new StringBuilder(basicSql);
         if (typeBasicTypeDefine.isNullable()) {
             sql.append("NULL ");
@@ -634,8 +630,7 @@ public interface JdbcDialect extends Serializable {
      * @param typeBasicTypeDefine type basic type define of new column
      * @return alter table sql with default value for sink table
      */
-    default String decorateWithDefaultValue(
-            String basicSql, BasicTypeDefine<MysqlType> typeBasicTypeDefine) {
+    default String decorateWithDefaultValue(String basicSql, BasicTypeDefine typeBasicTypeDefine) {
         Object defaultValue = typeBasicTypeDefine.getDefaultValue();
         if (Objects.nonNull(defaultValue)
                 && needsQuotesWithDefaultValue(typeBasicTypeDefine.getColumnType())
@@ -656,8 +651,7 @@ public interface JdbcDialect extends Serializable {
      * @param typeBasicTypeDefine type basic type define of new column
      * @return alter table sql with comment for sink table
      */
-    default String decorateWithComment(
-            String basicSql, BasicTypeDefine<MysqlType> typeBasicTypeDefine) {
+    default String decorateWithComment(String basicSql, BasicTypeDefine typeBasicTypeDefine) {
         String comment = typeBasicTypeDefine.getComment();
         StringBuilder sql = new StringBuilder(basicSql);
         if (StringUtils.isNotBlank(comment)) {
