@@ -23,7 +23,7 @@ import org.apache.http.impl.client.HttpClients;
 
 /** util to build http client. */
 public class HttpUtil {
-    public HttpUtil() {}
+    private HttpUtil() {}
 
     private static final HttpClientBuilder HTTP_CLIENT_BUILDER =
             HttpClients.custom().disableRedirectHandling();
