@@ -17,16 +17,25 @@
 
 package org.apache.seatunnel.connectors.seatunnel.starrocks.catalog;
 
+import org.apache.seatunnel.api.sink.SaveModePlaceHolder;
+import org.apache.seatunnel.api.table.catalog.CatalogTable;
 import org.apache.seatunnel.api.table.catalog.Column;
 import org.apache.seatunnel.api.table.catalog.ConstraintKey;
 import org.apache.seatunnel.api.table.catalog.PhysicalColumn;
 import org.apache.seatunnel.api.table.catalog.PrimaryKey;
+import org.apache.seatunnel.api.table.catalog.TableIdentifier;
+import org.apache.seatunnel.api.table.catalog.TablePath;
 import org.apache.seatunnel.api.table.catalog.TableSchema;
 import org.apache.seatunnel.api.table.type.BasicType;
 import org.apache.seatunnel.api.table.type.DecimalType;
 import org.apache.seatunnel.api.table.type.LocalTimeType;
+import org.apache.seatunnel.common.exception.CommonError;
+import org.apache.seatunnel.common.exception.SeaTunnelRuntimeException;
+import org.apache.seatunnel.connectors.seatunnel.starrocks.config.StarRocksSinkOptions;
 import org.apache.seatunnel.connectors.seatunnel.starrocks.sink.StarRocksSaveModeUtil;
 
+import org.apache.commons.lang3.StringUtils;
+
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.Test;
 
@@ -55,7 +64,7 @@ public class StarRocksCreateTableTest {
 
         String result =
                 StarRocksSaveModeUtil.getCreateTableSql(
-                        "CREATE TABLE IF NOT EXISTS `${database}`.`${table_name}` (                                                                                                                                                   \n"
+                        "CREATE TABLE IF NOT EXISTS `${database}`.`${table}` (                                                                                                                                                   \n"
                                 + "${rowtype_primary_key}  ,       \n"
                                 + "${rowtype_unique_key} , \n"
                                 + "`create_time` DATETIME NOT NULL ,  \n"
@@ -119,6 +128,41 @@ public class StarRocksCreateTableTest {
                         + "    \"dynamic_partition.prefix\" = \"p\"                                                                                                                                                                           \n"
                         + ");",
                 result);
+
+        CatalogTable catalogTable =
+                CatalogTable.of(
+                        TableIdentifier.of("test", "test1", "test2"),
+                        TableSchema.builder()
+                                .primaryKey(
+                                        PrimaryKey.of(StringUtils.EMPTY, Collections.emptyList()))
+                                .constraintKey(Collections.emptyList())
+                                .columns(columns)
+                                .build(),
+                        Collections.emptyMap(),
+                        Collections.emptyList(),
+                        "");
+        TablePath tablePath = TablePath.of("test1.test2");
+        String createTemplate = StarRocksSinkOptions.SAVE_MODE_CREATE_TEMPLATE.defaultValue();
+        RuntimeException actualSeaTunnelRuntimeException =
+                Assertions.assertThrows(
+                        RuntimeException.class,
+                        () ->
+                                StarRocksSaveModeUtil.getCreateTableSql(
+                                        createTemplate,
+                                        tablePath.getDatabaseName(),
+                                        tablePath.getTableName(),
+                                        catalogTable.getTableSchema()));
+        String primaryKeyHolder = SaveModePlaceHolder.ROWTYPE_PRIMARY_KEY.getPlaceHolder();
+        SeaTunnelRuntimeException exceptSeaTunnelRuntimeException =
+                CommonError.sqlTemplateHandledError(
+                        tablePath.getFullName(),
+                        SaveModePlaceHolder.getDisplay(primaryKeyHolder),
+                        createTemplate,
+                        primaryKeyHolder,
+                        StarRocksSinkOptions.SAVE_MODE_CREATE_TEMPLATE.key());
+        Assertions.assertEquals(
+                exceptSeaTunnelRuntimeException.getMessage(),
+                actualSeaTunnelRuntimeException.getMessage());
     }
 
     @Test
@@ -188,7 +232,7 @@ public class StarRocksCreateTableTest {
 
         String result =
                 StarRocksSaveModeUtil.getCreateTableSql(
-                        "CREATE TABLE IF NOT EXISTS `${database}`.`${table_name}` (\n"
+                        "CREATE TABLE IF NOT EXISTS `${database}`.`${table}` (\n"
                                 + "`L_COMMITDATE`,\n"
                                 + "${rowtype_primary_key},\n"
                                 + "L_SUPPKEY BIGINT NOT NULL,\n"
@@ -245,7 +289,7 @@ public class StarRocksCreateTableTest {
 
         String result =
                 StarRocksSaveModeUtil.getCreateTableSql(
-                        "CREATE TABLE IF NOT EXISTS `${database}`.`${table_name}` (                                                                                                                                                   \n"
+                        "CREATE TABLE IF NOT EXISTS `${database}`.`${table}` (                                                                                                                                                   \n"
                                 + "${rowtype_primary_key}  ,       \n"
                                 + "`create_time` DATETIME NOT NULL ,  \n"
                                 + "${rowtype_fields}  \n"
@@ -302,7 +346,7 @@ public class StarRocksCreateTableTest {
 
         String result =
                 StarRocksSaveModeUtil.getCreateTableSql(
-                        "create table '${database}'.'${table_name}'(\n"
+                        "create table '${database}'.'${table}'(\n"
                                 + "     ${rowtype_fields}\n"
                                 + " )\n"
                                 + " partitioned by ${rowtype_primary_key};",
