@@ -51,6 +51,7 @@ import java.util.stream.Collectors;
 import static org.apache.seatunnel.api.common.CommonOptions.PLUGIN_NAME;
 import static org.apache.seatunnel.api.common.SeaTunnelAPIErrorCode.HANDLE_SAVE_MODE_FAILED;
 
+@SuppressWarnings({"unchecked", "rawtypes"})
 public class SinkExecuteProcessor
         extends FlinkAbstractPluginExecuteProcessor<Optional<? extends Factory>> {
 
@@ -107,12 +108,15 @@ public class SinkExecuteProcessor
                                         sinkConfig.getString(PLUGIN_NAME.key())),
                                 sinkConfig);
                 sink.setJobContext(jobContext);
-                SeaTunnelRowType sourceType = stream.getCatalogTable().getSeaTunnelRowType();
+                // TODO support sink multi sink
+                SeaTunnelRowType sourceType =
+                        stream.getCatalogTables().get(0).getSeaTunnelRowType();
                 sink.setTypeInfo(sourceType);
             } else {
+                // TODO support sink multi sink
                 TableSinkFactoryContext context =
                         TableSinkFactoryContext.replacePlaceholderAndCreate(
-                                stream.getCatalogTable(),
+                                stream.getCatalogTables().get(0),
                                 ReadonlyConfig.fromConfig(sinkConfig),
                                 classLoader,
                                 ((TableSinkFactory) factory.get())
@@ -134,8 +138,8 @@ public class SinkExecuteProcessor
             }
             DataStreamSink<Row> dataStreamSink =
                     stream.getDataStream()
-                            .sinkTo(new FlinkSink<>(sink, stream.getCatalogTable()))
-                            .name(sink.getPluginName());
+                            .sinkTo(new FlinkSink<>(sink, stream.getCatalogTables().get(0)))
+                            .name(String.format("%s-Sink", sink.getPluginName()));
             if (sinkConfig.hasPath(CommonOptions.PARALLELISM.key())) {
                 int parallelism = sinkConfig.getInt(CommonOptions.PARALLELISM.key());
                 dataStreamSink.setParallelism(parallelism);
