@@ -37,7 +37,6 @@ import lombok.extern.slf4j.Slf4j;
 
 import java.util.ArrayList;
 import java.util.List;
-import java.util.Objects;
 
 @EqualsAndHashCode(callSuper = true)
 @Data
@@ -79,6 +78,11 @@ public class ClientCommandArgs extends AbstractCommandArgs {
             description = "Get job metrics by JobId")
     private String metricsJobId;
 
+    @Parameter(
+            names = {"--set-job-id"},
+            description = "Set custom job id for job")
+    private String customJobId;
+
     @Parameter(
             names = {"--get_running_job_metrics"},
             description = "Gets metrics for running jobs")
@@ -103,7 +107,6 @@ public class ClientCommandArgs extends AbstractCommandArgs {
     @Override
     public Command<?> buildCommand() {
         Common.setDeployMode(getDeployMode());
-        userParamsToSysEnv();
         if (checkConfig) {
             return new SeaTunnelConfValidateCommand(this);
         }
@@ -116,16 +119,6 @@ public class ClientCommandArgs extends AbstractCommandArgs {
         return new ClientExecuteCommand(this);
     }
 
-    private void userParamsToSysEnv() {
-        if (!this.variables.isEmpty()) {
-            variables.stream()
-                    .filter(Objects::nonNull)
-                    .map(variable -> variable.split("=", 2))
-                    .filter(pair -> pair.length == 2)
-                    .forEach(pair -> System.setProperty(pair[0], pair[1]));
-        }
-    }
-
     public DeployMode getDeployMode() {
         return DeployMode.CLIENT;
     }
