@@ -50,7 +50,7 @@ CREATE TABLE mysql_cdc_e2e_source_table
     `f_mediumtext`         mediumtext,
     `f_text`               text,
     `f_tinytext`           tinytext,
-    `f_varchar`            varchar(100)                   DEFAULT NULL,
+    `f_varchar`            varchar(100) collate gbk_bin   DEFAULT NULL,
     `f_date`               date                           DEFAULT NULL,
     `f_datetime`           datetime                       DEFAULT NULL,
     `f_timestamp`          timestamp NULL                 DEFAULT NULL,
@@ -333,7 +333,7 @@ VALUES ( 1, 0x616263740000000000000000000000000000000000000000000000000000000000
          0x68656C6C6F, 0x18000000789C0BC9C82C5600A244859CFCBC7485B2C4A2A4CCBCC4A24A00697308D4, NULL,
          0x74696E79626C6F62, 0x48656C6C6F20776F726C64, 12345, 54321, 123456, 654321, 1234567, 7654321, 1234567, 7654321,
          123456789, 987654321, 123, 789, 12.34, 56.78, 90.12, 'This is a long text field', 'This is a medium text field',
-         'This is a text field', 'This is a tiny text field', 'This is a varchar field', '2022-04-27', '2022-04-27 14:30:00',
+         'This is a text field', 'This is a tiny text field', '中文测试', '2022-04-27', '2022-04-27 14:30:00',
          '2023-04-27 11:08:40', 1, b'0101010101010101010101010101010101010101010101010101010101010101', 'C', 'enum2',
          0x1B000000789C0BC9C82C5600A24485DCD494CCD25C85A49CFC2485B4CCD49C140083FF099A, 'This is a long varchar field',
          12.345, '14:30:00', -128, 255, '{ "key": "value" }', 2022 ),
