@@ -95,6 +95,12 @@ import static org.awaitility.Awaitility.given;
 public class KafkaFormatIT extends TestSuiteBase implements TestResource {
 
     private static final Logger LOG = LoggerFactory.getLogger(KafkaFormatIT.class);
+
+    // ---------------------------MaxWell Format Parameter---------------------------------------
+    private static final String MAXWELL_DATA_PATH = "/maxwell/maxwell_data.txt";
+    private static final String MAXWELL_KAFKA_SOURCE_TOPIC = "maxwell-test-cdc_mds";
+    private static final String MAXWELL_KAFKA_SINK_TOPIC = "test-maxwell-sink";
+
     // ---------------------------Ogg Format Parameter---------------------------------------
     private static final String OGG_DATA_PATH = "/ogg/ogg_data.txt";
     private static final String OGG_KAFKA_SOURCE_TOPIC = "test-ogg-source";
@@ -103,7 +109,6 @@ public class KafkaFormatIT extends TestSuiteBase implements TestResource {
     // ---------------------------Canal Format Parameter---------------------------------------
 
     private static final String CANAL_KAFKA_SINK_TOPIC = "test-canal-sink";
-    private static final String CANAL_MYSQL_DATABASE = "canal";
     private static final String CANAL_DATA_PATH = "/canal/canal_data.txt";
     private static final String CANAL_KAFKA_SOURCE_TOPIC = "test-cdc_mds";
 
@@ -240,6 +245,7 @@ public class KafkaFormatIT extends TestSuiteBase implements TestResource {
                     {
                         put(CANAL_DATA_PATH, CANAL_KAFKA_SOURCE_TOPIC);
                         put(OGG_DATA_PATH, OGG_KAFKA_SOURCE_TOPIC);
+                        put(MAXWELL_DATA_PATH, MAXWELL_KAFKA_SOURCE_TOPIC);
                         put(COMPATIBLE_DATA_PATH, COMPATIBLE_KAFKA_SOURCE_TOPIC);
                         put(DEBEZIUM_DATA_PATH, DEBEZIUM_KAFKA_SOURCE_TOPIC);
                     }
@@ -332,6 +338,24 @@ public class KafkaFormatIT extends TestSuiteBase implements TestResource {
         Thread.sleep(20 * 1000);
     }
 
+    @DisabledOnContainer(
+            value = {},
+            type = {EngineType.SPARK, EngineType.FLINK},
+            disabledReason = "The multi-catalog does not currently support the Spark Flink engine")
+    @TestTemplate
+    public void testMultiFormatCheck(TestContainer container)
+            throws IOException, InterruptedException {
+        LOG.info(
+                "====================== Multi Source Format Canal and Ogg Check  ======================");
+        Container.ExecResult execCanalAndOggResultKafka =
+                container.executeJob("/multiFormatIT/kafka_multi_source_to_pg.conf");
+        Assertions.assertEquals(
+                0,
+                execCanalAndOggResultKafka.getExitCode(),
+                execCanalAndOggResultKafka.getStderr());
+        checkFormatCanalAndOgg();
+    }
+
     @TestTemplate
     public void testFormatCanalCheck(TestContainer container)
             throws IOException, InterruptedException {
@@ -401,7 +425,141 @@ public class KafkaFormatIT extends TestSuiteBase implements TestResource {
         checkCompatibleFormat();
     }
 
+    @TestTemplate
+    public void testFormatMaxWellCheck(TestContainer container)
+            throws IOException, InterruptedException {
+
+        LOG.info("====================== Check MaxWell======================");
+        // check MaxWell to Postgresql
+        Container.ExecResult checkMaxWellResultToKafka =
+                container.executeJob("/maxwellFormatIT/kafkasource_maxwell_to_kafka.conf");
+        Assertions.assertEquals(
+                0, checkMaxWellResultToKafka.getExitCode(), checkMaxWellResultToKafka.getStderr());
+
+        Container.ExecResult checkDataResult =
+                container.executeJob("/maxwellFormatIT/kafkasource_maxwell_cdc_to_pgsql.conf");
+        Assertions.assertEquals(0, checkDataResult.getExitCode(), checkDataResult.getStderr());
+
+        // Check MaxWell
+        checkMaxWellFormat();
+    }
+
+    private void checkFormatCanalAndOgg() {
+        List<List<Object>> postgreSinkTableList = getPostgreSinkTableList(PG_SINK_TABLE1);
+        List<List<Object>> checkArraysResult =
+                Stream.<List<Object>>of(
+                                Arrays.asList(
+                                        101,
+                                        "scooter",
+                                        "Small 2-wheel scooter",
+                                        "3.140000104904175"),
+                                Arrays.asList(
+                                        102, "car battery", "12V car battery", "8.100000381469727"),
+                                Arrays.asList(
+                                        103,
+                                        "12-pack drill bits",
+                                        "12-pack of drill bits with sizes ranging from #40 to #3",
+                                        "0.800000011920929"),
+                                Arrays.asList(104, "hammer", "12oz carpenter's hammer", "0.75"),
+                                Arrays.asList(105, "hammer", "14oz carpenter's hammer", "0.875"),
+                                Arrays.asList(106, "hammer", "18oz carpenter hammer", "1"),
+                                Arrays.asList(
+                                        107, "rocks", "box of assorted rocks", "5.099999904632568"),
+                                Arrays.asList(
+                                        108,
+                                        "jacket",
+                                        "water resistent black wind breaker",
+                                        "0.10000000149011612"),
+                                Arrays.asList(
+                                        109,
+                                        "spare tire",
+                                        "24 inch spare tire",
+                                        "22.200000762939453"),
+                                Arrays.asList(
+                                        110,
+                                        "jacket",
+                                        "new water resistent white wind breaker",
+                                        "0.5"),
+                                Arrays.asList(1101, "scooter", "Small 2-wheel scooter", "4.56"),
+                                Arrays.asList(1102, "car battery", "12V car battery", "8.1"),
+                                Arrays.asList(
+                                        1103,
+                                        "12-pack drill bits",
+                                        "12-pack of drill bits with sizes ranging from #40 to #3",
+                                        "0.8"),
+                                Arrays.asList(1104, "hammer", "12oz carpenter's hammer", "0.75"),
+                                Arrays.asList(1105, "hammer", "14oz carpenter's hammer", "0.875"),
+                                Arrays.asList(1106, "hammer", "16oz carpenter's hammer", "1.0"),
+                                Arrays.asList(1107, "rocks", "box of assorted rocks", "7.88"),
+                                Arrays.asList(
+                                        1108,
+                                        "jacket",
+                                        "water resistent black wind breaker",
+                                        "0.1"))
+                        .collect(Collectors.toList());
+        Assertions.assertIterableEquals(postgreSinkTableList, checkArraysResult);
+    }
+
     private void checkCanalFormat() {
+        List<String> expectedResult =
+                Arrays.asList(
+                        "{\"data\":{\"id\":1101,\"name\":\"scooter\",\"description\":\"Small 2-wheel scooter\",\"weight\":\"3.14\"},\"type\":\"INSERT\"}",
+                        "{\"data\":{\"id\":1102,\"name\":\"car battery\",\"description\":\"12V car battery\",\"weight\":\"8.1\"},\"type\":\"INSERT\"}",
+                        "{\"data\":{\"id\":1103,\"name\":\"12-pack drill bits\",\"description\":\"12-pack of drill bits with sizes ranging from #40 to #3\",\"weight\":\"0.8\"},\"type\":\"INSERT\"}",
+                        "{\"data\":{\"id\":1104,\"name\":\"hammer\",\"description\":\"12oz carpenter's hammer\",\"weight\":\"0.75\"},\"type\":\"INSERT\"}",
+                        "{\"data\":{\"id\":1105,\"name\":\"hammer\",\"description\":\"14oz carpenter's hammer\",\"weight\":\"0.875\"},\"type\":\"INSERT\"}",
+                        "{\"data\":{\"id\":1106,\"name\":\"hammer\",\"description\":\"16oz carpenter's hammer\",\"weight\":\"1.0\"},\"type\":\"INSERT\"}",
+                        "{\"data\":{\"id\":1107,\"name\":\"rocks\",\"description\":\"box of assorted rocks\",\"weight\":\"5.3\"},\"type\":\"INSERT\"}",
+                        "{\"data\":{\"id\":1108,\"name\":\"jacket\",\"description\":\"water resistent black wind breaker\",\"weight\":\"0.1\"},\"type\":\"INSERT\"}",
+                        "{\"data\":{\"id\":1109,\"name\":\"spare tire\",\"description\":\"24 inch spare tire\",\"weight\":\"22.2\"},\"type\":\"INSERT\"}",
+                        "{\"data\":{\"id\":1101,\"name\":\"scooter\",\"description\":\"Small 2-wheel scooter\",\"weight\":\"3.14\"},\"type\":\"DELETE\"}",
+                        "{\"data\":{\"id\":1101,\"name\":\"scooter\",\"description\":\"Small 2-wheel scooter\",\"weight\":\"4.56\"},\"type\":\"INSERT\"}",
+                        "{\"data\":{\"id\":1107,\"name\":\"rocks\",\"description\":\"box of assorted rocks\",\"weight\":\"5.3\"},\"type\":\"DELETE\"}",
+                        "{\"data\":{\"id\":1107,\"name\":\"rocks\",\"description\":\"box of assorted rocks\",\"weight\":\"7.88\"},\"type\":\"INSERT\"}",
+                        "{\"data\":{\"id\":1109,\"name\":\"spare tire\",\"description\":\"24 inch spare tire\",\"weight\":\"22.2\"},\"type\":\"DELETE\"}");
+
+        ArrayList<String> result = new ArrayList<>();
+        ArrayList<String> topics = new ArrayList<>();
+        topics.add(CANAL_KAFKA_SINK_TOPIC);
+        kafkaConsumer.subscribe(topics);
+        await().atMost(60000, TimeUnit.MILLISECONDS)
+                .untilAsserted(
+                        () -> {
+                            ConsumerRecords<String, String> consumerRecords =
+                                    kafkaConsumer.poll(Duration.ofMillis(1000));
+                            for (ConsumerRecord<String, String> record : consumerRecords) {
+                                result.add(record.value());
+                            }
+                            Assertions.assertEquals(expectedResult, result);
+                        });
+
+        LOG.info("==================== start kafka canal format to pg check ====================");
+
+        List<List<Object>> postgreSinkTableList = getPostgreSinkTableList(PG_SINK_TABLE1);
+
+        List<List<Object>> expected =
+                Stream.<List<Object>>of(
+                                Arrays.asList(1101, "scooter", "Small 2-wheel scooter", "4.56"),
+                                Arrays.asList(1102, "car battery", "12V car battery", "8.1"),
+                                Arrays.asList(
+                                        1103,
+                                        "12-pack drill bits",
+                                        "12-pack of drill bits with sizes ranging from #40 to #3",
+                                        "0.8"),
+                                Arrays.asList(1104, "hammer", "12oz carpenter's hammer", "0.75"),
+                                Arrays.asList(1105, "hammer", "14oz carpenter's hammer", "0.875"),
+                                Arrays.asList(1106, "hammer", "16oz carpenter's hammer", "1.0"),
+                                Arrays.asList(1107, "rocks", "box of assorted rocks", "7.88"),
+                                Arrays.asList(
+                                        1108,
+                                        "jacket",
+                                        "water resistent black wind breaker",
+                                        "0.1"))
+                        .collect(Collectors.toList());
+        Assertions.assertIterableEquals(expected, postgreSinkTableList);
+    }
+
+    private void checkMaxWellFormat() {
         List<String> expectedResult =
                 Arrays.asList(
                         "{\"data\":{\"id\":101,\"name\":\"scooter\",\"description\":\"Small 2-wheel scooter\",\"weight\":\"3.14\"},\"type\":\"INSERT\"}",
@@ -421,7 +579,7 @@ public class KafkaFormatIT extends TestSuiteBase implements TestResource {
 
         ArrayList<String> result = new ArrayList<>();
         ArrayList<String> topics = new ArrayList<>();
-        topics.add(CANAL_KAFKA_SINK_TOPIC);
+        topics.add(MAXWELL_KAFKA_SINK_TOPIC);
         kafkaConsumer.subscribe(topics);
         await().atMost(60000, TimeUnit.MILLISECONDS)
                 .untilAsserted(
@@ -434,7 +592,8 @@ public class KafkaFormatIT extends TestSuiteBase implements TestResource {
                             Assertions.assertEquals(expectedResult, result);
                         });
 
-        LOG.info("==================== start kafka canal format to pg check ====================");
+        LOG.info(
+                "==================== start kafka MaxWell format to pg check ====================");
 
         List<List<Object>> postgreSinkTableList = getPostgreSinkTableList(PG_SINK_TABLE1);
 
