@@ -74,9 +74,6 @@ import static java.lang.String.format;
 import static org.awaitility.Awaitility.await;
 
 @Slf4j
-@DisabledOnContainer(
-        value = {},
-        disabledReason = "Override TestSuiteBase @DisabledOnContainer")
 public class KuduIT extends TestSuiteBase implements TestResource {
 
     private static final String IMAGE = "apache/kudu:1.15.0";
