@@ -771,7 +771,7 @@ public class ClusterFaultToleranceIT {
                             + "          type: hdfs\n"
                             + "          namespace: /tmp/seatunnel/imap\n"
                             + "          clusterName: "
-                            + testClusterName
+                            + TestUtils.getClusterName(testClusterName)
                             + "\n"
                             + "          fs.defaultFS: file:///\n"
                             + "\n"
@@ -839,6 +839,7 @@ public class ClusterFaultToleranceIT {
             // shutdown all node
             node1.shutdown();
             node2.shutdown();
+            engineClient.close();
 
             log.warn(
                     "==========================================All node is done========================================");
@@ -977,7 +978,7 @@ public class ClusterFaultToleranceIT {
                             + "          namespace: /seatunnel-test/imap\n"
                             + "          storage.type: oss\n"
                             + "          clusterName: "
-                            + testClusterName
+                            + TestUtils.getClusterName(testClusterName)
                             + "\n"
                             + "          oss.bucket: "
                             + OSS_BUCKET_NAME
