@@ -29,6 +29,7 @@ import lombok.AllArgsConstructor;
 import lombok.Data;
 
 import java.io.IOException;
+import java.util.Map;
 
 /**
  * Used to describe the status of the current Worker, including address and resource assign status
@@ -43,10 +44,14 @@ public class WorkerProfile implements IdentifiedDataSerializable {
 
     private ResourceProfile unassignedResource;
 
+    private boolean dynamicSlot;
+
     private SlotProfile[] assignedSlots;
 
     private SlotProfile[] unassignedSlots;
 
+    private Map<String, String> attributes;
+
     public WorkerProfile(Address address) {
         this.address = address;
         this.unassignedResource = new ResourceProfile();
@@ -79,6 +84,7 @@ public class WorkerProfile implements IdentifiedDataSerializable {
         for (SlotProfile unassignedSlot : unassignedSlots) {
             out.writeObject(unassignedSlot);
         }
+        out.writeBoolean(dynamicSlot);
     }
 
     @Override
@@ -96,5 +102,6 @@ public class WorkerProfile implements IdentifiedDataSerializable {
         for (int i = 0; i < unassignedSlots.length; i++) {
             unassignedSlots[i] = in.readObject();
         }
+        dynamicSlot = in.readBoolean();
     }
 }
