@@ -18,6 +18,7 @@
 package org.apache.seatunnel.engine.server.task;
 
 import org.apache.seatunnel.api.serialization.Serializer;
+import org.apache.seatunnel.api.source.Boundedness;
 import org.apache.seatunnel.api.source.SourceEvent;
 import org.apache.seatunnel.api.source.SourceSplit;
 import org.apache.seatunnel.api.source.SourceSplitEnumerator;
@@ -32,12 +33,12 @@ import org.apache.seatunnel.engine.server.execution.ProgressState;
 import org.apache.seatunnel.engine.server.execution.TaskLocation;
 import org.apache.seatunnel.engine.server.task.context.SeaTunnelSplitEnumeratorContext;
 import org.apache.seatunnel.engine.server.task.operation.checkpoint.BarrierFlowOperation;
+import org.apache.seatunnel.engine.server.task.operation.source.CloseIdleReaderOperation;
 import org.apache.seatunnel.engine.server.task.operation.source.LastCheckpointNotifyOperation;
 import org.apache.seatunnel.engine.server.task.record.Barrier;
 import org.apache.seatunnel.engine.server.task.statemachine.SeaTunnelTaskState;
 
 import com.hazelcast.cluster.Address;
-import com.hazelcast.spi.impl.operationservice.Operation;
 import com.hazelcast.spi.impl.operationservice.impl.InvocationFuture;
 import lombok.NonNull;
 import lombok.extern.slf4j.Slf4j;
@@ -57,7 +58,6 @@ import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.CopyOnWriteArraySet;
 import java.util.concurrent.ExecutionException;
-import java.util.function.Function;
 import java.util.stream.Collectors;
 
 import static org.apache.seatunnel.engine.common.utils.ExceptionUtil.sneaky;
@@ -144,7 +144,7 @@ public class SourceSplitEnumeratorTask<SplitT extends SourceSplit> extends Coord
         long startTime = System.currentTimeMillis();
 
         log.debug("split enumer trigger barrier [{}]", barrier);
-        if (barrier.prepareClose()) {
+        if (barrier.prepareClose(this.taskLocation)) {
             this.prepareCloseTriggered = true;
             this.prepareCloseBarrierId.set(barrier.getId());
         }
@@ -158,7 +158,7 @@ public class SourceSplitEnumeratorTask<SplitT extends SourceSplit> extends Coord
                 serialize = enumeratorStateSerializer.serialize(snapshotState);
             }
             log.debug("source split enumerator send state [{}] to master", snapshotState);
-            sendToAllReader(location -> new BarrierFlowOperation(barrier, location));
+            sendToActiveReader(barrier);
         }
         if (barrier.snapshot()) {
             this.getExecutionContext()
@@ -208,7 +208,7 @@ public class SourceSplitEnumeratorTask<SplitT extends SourceSplit> extends Coord
         return splitSerializer;
     }
 
-    public void addSplitsBack(List<SplitT> splits, int subtaskId)
+    public synchronized void addSplitsBack(List<SplitT> splits, int subtaskId)
             throws ExecutionException, InterruptedException {
         getEnumerator().addSplitsBack(splits, subtaskId);
     }
@@ -276,10 +276,18 @@ public class SourceSplitEnumeratorTask<SplitT extends SourceSplit> extends Coord
         return enumerator;
     }
 
-    public void readerFinished(long taskID) {
-        unfinishedReaders.remove(taskID);
+    public void readerFinished(TaskLocation taskLocation) {
+        unfinishedReaders.remove(taskLocation.getTaskID());
         if (unfinishedReaders.isEmpty()) {
             prepareCloseStatus = true;
+        } else if (Boundedness.UNBOUNDED.equals(this.source.getSource().getBoundedness())) {
+            log.info(
+                    "Send close idle reader {} operation of unbounded job. {}",
+                    taskLocation.getTaskIndex(),
+                    taskLocation);
+            this.getExecutionContext()
+                    .sendToMaster(new CloseIdleReaderOperation(jobID, taskLocation))
+                    .join();
         }
     }
 
@@ -348,10 +356,13 @@ public class SourceSplitEnumeratorTask<SplitT extends SourceSplit> extends Coord
                 .collect(Collectors.toSet());
     }
 
-    private void sendToAllReader(Function<TaskLocation, Operation> function) {
+    private void sendToActiveReader(Barrier barrier) {
         List<InvocationFuture<?>> futures = new ArrayList<>();
         taskMemberMapping.forEach(
                 (location, address) -> {
+                    if (barrier.closedTasks().contains(location)) {
+                        return;
+                    }
                     log.debug(
                             "split enumerator send to read--size: {}, location: {}, address: {}",
                             taskMemberMapping.size(),
@@ -359,7 +370,8 @@ public class SourceSplitEnumeratorTask<SplitT extends SourceSplit> extends Coord
                             address.toString());
                     futures.add(
                             this.getExecutionContext()
-                                    .sendToMember(function.apply(location), address));
+                                    .sendToMember(
+                                            new BarrierFlowOperation(barrier, location), address));
                 });
         futures.forEach(InvocationFuture::join);
     }
