@@ -23,7 +23,11 @@ import org.apache.seatunnel.api.table.type.SeaTunnelRowType;
 import java.util.List;
 
 public interface SQLEngine {
-    void init(String inputTableName, SeaTunnelRowType inputRowType, String sql);
+    void init(
+            String inputTableName,
+            String catalogTableName,
+            SeaTunnelRowType inputRowType,
+            String sql);
 
     SeaTunnelRowType typeMapping(List<String> inputColumnsMapping);
 
