@@ -49,6 +49,7 @@ public class CoordinatedSource<T, SplitT extends SourceSplit, StateT extends Ser
     protected final SeaTunnelSource<T, SplitT, StateT> source;
     protected final Map<Integer, List<byte[]>> restoredState;
     protected final Integer parallelism;
+    protected final String jobId;
 
     protected final Serializer<SplitT> splitSerializer;
     protected final Serializer<StateT> enumeratorStateSerializer;
@@ -69,14 +70,16 @@ public class CoordinatedSource<T, SplitT extends SourceSplit, StateT extends Ser
     public CoordinatedSource(
             SeaTunnelSource<T, SplitT, StateT> source,
             Map<Integer, List<byte[]>> restoredState,
-            int parallelism) {
+            int parallelism,
+            String jobId) {
         this.source = source;
         this.restoredState = restoredState;
         this.parallelism = parallelism;
+        this.jobId = jobId;
         this.splitSerializer = source.getSplitSerializer();
         this.enumeratorStateSerializer = source.getEnumeratorStateSerializer();
 
-        this.coordinatedEnumeratorContext = new CoordinatedEnumeratorContext<>(this);
+        this.coordinatedEnumeratorContext = new CoordinatedEnumeratorContext<>(this, jobId);
         this.readerContextMap = new ConcurrentHashMap<>(parallelism);
         this.readerRunningMap = new ConcurrentHashMap<>(parallelism);
         try {
@@ -119,7 +122,7 @@ public class CoordinatedSource<T, SplitT extends SourceSplit, StateT extends Ser
     private void createReaders() throws Exception {
         for (int subtaskId = 0; subtaskId < this.parallelism; subtaskId++) {
             CoordinatedReaderContext readerContext =
-                    new CoordinatedReaderContext(this, source.getBoundedness(), subtaskId);
+                    new CoordinatedReaderContext(this, source.getBoundedness(), jobId, subtaskId);
             readerContextMap.put(subtaskId, readerContext);
             readerRunningMap.put(subtaskId, new AtomicBoolean(true));
             SourceReader<T, SplitT> reader = source.createReader(readerContext);
