@@ -45,6 +45,7 @@ public class ParallelSource<T, SplitT extends SourceSplit, StateT extends Serial
     protected final SeaTunnelSource<T, SplitT, StateT> source;
     protected final ParallelEnumeratorContext<SplitT> parallelEnumeratorContext;
     protected final ParallelReaderContext readerContext;
+    protected final String jobId;
     protected final Integer subtaskId;
     protected final Integer parallelism;
 
@@ -64,16 +65,19 @@ public class ParallelSource<T, SplitT extends SourceSplit, StateT extends Serial
             SeaTunnelSource<T, SplitT, StateT> source,
             Map<Integer, List<byte[]>> restoredState,
             int parallelism,
+            String jobId,
             int subtaskId) {
         this.source = source;
+        this.jobId = jobId;
         this.subtaskId = subtaskId;
         this.parallelism = parallelism;
 
         this.splitSerializer = source.getSplitSerializer();
         this.enumeratorStateSerializer = source.getEnumeratorStateSerializer();
         this.parallelEnumeratorContext =
-                new ParallelEnumeratorContext<>(this, parallelism, subtaskId);
-        this.readerContext = new ParallelReaderContext(this, source.getBoundedness(), subtaskId);
+                new ParallelEnumeratorContext<>(this, parallelism, jobId, subtaskId);
+        this.readerContext =
+                new ParallelReaderContext(this, source.getBoundedness(), jobId, subtaskId);
 
         // Create or restore split enumerator & reader
         try {
