@@ -35,14 +35,17 @@ import java.util.Map;
 public class BatchSourceReader implements DataSourceReader {
 
     protected final SeaTunnelSource<SeaTunnelRow, ?, ?> source;
+    protected final String jobId;
     protected final Integer parallelism;
     private Map<String, String> envOptions;
 
     public BatchSourceReader(
             SeaTunnelSource<SeaTunnelRow, ?, ?> source,
+            String jobId,
             Integer parallelism,
             Map<String, String> envOptions) {
         this.source = source;
+        this.jobId = jobId;
         this.parallelism = parallelism;
         this.envOptions = envOptions;
     }
@@ -57,12 +60,12 @@ public class BatchSourceReader implements DataSourceReader {
         List<InputPartition<InternalRow>> virtualPartitions;
         if (source instanceof SupportCoordinate) {
             virtualPartitions = new ArrayList<>(1);
-            virtualPartitions.add(new BatchPartition(source, parallelism, 0, envOptions));
+            virtualPartitions.add(new BatchPartition(source, parallelism, jobId, 0, envOptions));
         } else {
             virtualPartitions = new ArrayList<>(parallelism);
             for (int subtaskId = 0; subtaskId < parallelism; subtaskId++) {
                 virtualPartitions.add(
-                        new BatchPartition(source, parallelism, subtaskId, envOptions));
+                        new BatchPartition(source, parallelism, jobId, subtaskId, envOptions));
             }
         }
         return virtualPartitions;
